/** 
 @file device-radio-groups.js
 
 @brief This file contains implementation of custom fields for dialog "Device Configuration"

 @author: Grega

 @date: 20.06.2013
*/


/** 
 @brief Creates custom field derived from RadioGroup for selecting Input Mode (standard or inverted )
 
 @param 
  
 @return Input mode: false-standard, true-inverted
*/
Ext.define('DSS.component.DeviceInputModeDelay', {
    extend : 'DSS.component.Base',
    mixins : {
        observable : 'Ext.util.Observable'
    },
    getHeight:function () {
                 return 90;
    },
    inputMode:null,
    offDelay:null,
    isDevicePresent:false,
    constructor : function(config) {
       var me = this;
       
       
       this.inputMode = Ext.create('Ext.form.RadioGroup', {
            fieldLabel : _('Input Mode'),
            items : [ {
                inputValue : false,
                boxLabel : _('Input Mode Standard'),
                name : 'isInverted'
            }, {
                inputValue : true,
                boxLabel : _('Input Mode Inverted'),
                name : 'isInverted'
            } ],
            columns : 1,
            padding : '0 0 8 0',
        });        
        this.offDelay  = Ext.create('DSS.component.TimeSpanControl', {
            fieldLabel :  _('Switch off delay'),
            hideHour : true,
            invalidText : _('The value in this field is invalid'),
        });        
        
        this.rowPanel = Ext.create('Ext.panel.Panel', {
            border : false,
            autoScroll : false, 
            height : 90,
            layout : {
                type : 'vbox',
                flex:0
            },
            items : [ this.inputMode, 
                      this.offDelay]
        });
        

        Ext.apply(this, {
            items : [ this.rowPanel ]
        });       
        
          
        this.callParent(arguments);
    },
    reset: function (){
      this.inputMode.setValue(false);
      this.offDelay.setValue(0);
    },
    setValue:function (value){
        var waitDialog = new Ext.LoadMask(Ext.getBody(), {msg:_('Please wait, reading info from device ...')});
        waitDialog.show();
        var sDeviceID = this.dssEditor.editControls.dSID.getValue();

        // Input Mode - Read from device and set value to input control
        var bInverted = false;
        var sValue=dss.ajaxSyncRequest('/json/property/getString',{path:'/apartment/zones/zone0/devices/'+sDeviceID+'/AKMInputProperty'});
        var oValue=JSON.parse(sValue);
        if (oValue!=null && oValue.result!=null && oValue.result.value == 'inverted') 
          bInverted = true;
        this.inputMode.setValue({isInverted:bInverted});
        
        // Switch off delay - Read from device and set value to input control
        this.isDevicePresent = false;
        this.offDelay.disable();
        this.offDelay.setValue(0);
        var nDelay = 0; 
        sValue=dss.ajaxSyncRequest('/json/device/getAKMInputTimeouts',{dsid:sDeviceID});
        oValue=JSON.parse(sValue);
        waitDialog.hide();
     
        this.dssEditor.displayBottomText.setValue("");       
        if (oValue!=null && oValue.ok && oValue.result!=null) {
          if (oValue.result.offdelay >= 0) {
            nDelay = Math.floor(oValue.result.offdelay / 1000);
            this.offDelay.enable();
            this.isDevicePresent = true;
          }
        } 
        else {
          // error reading from device
          this.dssEditor.displayBottomText.setValue(_('Device is not accessible. Saving values to device is disabled.'));        
          var messageBox = Ext.create('Ext.window.MessageBox', {
                   buttonText: {
                       ok: _('Ok')
                   }
               });
                         
               messageBox.show({
                 title:_('Error accessing device'),
                 msg: _('Device is not accessible. Saving values to device is disabled.'),
                 buttons:Ext.MessageBox.OK,                
                 icon: Ext.Msg.WARNING,
            });
            this.offDelay.markInvalid();
        }
        
        this.offDelay.setValue(nDelay); 
    },
    isValid:function(){
        return true;
    },
    getValue : function(){
      var returnValue = new Object();
      returnValue.invertedMode = this.inputMode.getValue();
      returnValue.offDelay = this.offDelay.getValue();
      returnValue.isDevicePresent = this.isDevicePresent;
      return returnValue;

    }
});

/** 
 @brief Creates custom field derived from RadioGroup for selecting Sensor Function (App Mode, Motion Detector or Twilight Sensor)
 
 @param 
  
 @return Sensor Function: 0-App Mode, 5-Motion Detector, 4-Twilight Sensor
*/

Ext.define('DSS.component.DeviceSensorFunction', {
    extend : 'DSS.component.Base',
    mixins : {
        observable : 'Ext.util.Observable'
    },
    getHeight:function () {
                 return 150;
    },
    inputSensorType:null,
    returnValue: false,
    rowPanelRooms:null,
    rowPanelName:null,
    comboRooms:null,
    editDeviceName:null,
    constructor : function(config) {
       var me = this;
       
       var arrayRooms = new Array();
       if (dss.staticDataModel.nameCache == null) 
         dss.staticDataModel.initCaches()
       if (dss.staticDataModel.nameCache != null) {
         for ( var iIndex = 0; iIndex < dss.staticDataModel.nameCache.length; iIndex++) {
            var oZone = dss.staticDataModel.nameCache[iIndex];
            if (oZone.ZoneID > 0) {
              arrayRooms.push({"roomID":oZone.ZoneID,
                               "roomName":oZone.name});
            }
         } 
       }
       var storeData=Ext.create('Ext.data.Store', {
                           fields : [  "roomID", "roomName" ],
                           proxy : {
                               type : 'memory',
                               reader : {
                                   type : 'json',
                                   root : 'items'
                               }
                           }
                       });    
       storeData.add(arrayRooms);  
       

       this.editDeviceName = Ext.create('Ext.form.Text', {
           fieldLabel: _('Name'),
           width: 460,
       });  
            
       this.rowPanelName = Ext.create('Ext.container.Container', {
            defaultType : 'numberfield',
            items : [this.editDeviceName ],
            layout : 'column',
            padding : '0 0 8 0',
            width : 460
        });

       this.comboRooms  = Ext.create('Ext.form.field.ComboBox', {
                   store: storeData,           
                   queryMode: 'local',
                   displayField: 'roomName',
                   valueField: 'roomID',                    
                   fieldLabel :  _('Room'),
                   width : 460,
               });
               
       this.rowPanelRooms = Ext.create('Ext.container.Container', {
            defaultType : 'numberfield',
            items : [this.comboRooms ],
            layout : 'column',
            padding : '0 0 8 0',
            width : 460
        });
       
       this.inputSensorType = Ext.create('Ext.form.RadioGroup', {
            fieldLabel : _('Sensor Function'),
            items : [ {
                inputValue : 0,
                boxLabel : _('MD Normal'),
                name : 'deviceMDMode'
            }, {
                inputValue : 5,
                boxLabel : _('MD Motion Detector'),
                name : 'deviceMDMode'
            },{
                inputValue : 4,
                boxLabel : _('MD Twilight Sensor'),
                name : 'deviceMDMode'
            } ],
            columns : 1,
            padding : '4 0 8 0',
            listeners: {
              change: function(radiogroup, radio) {
                me.returnValue = radio.deviceMDMode;
              }
            }
        });        

        Ext.apply(this, {
            items : [ this.rowPanelName,
                      this.rowPanelRooms, 
                      this.inputSensorType ]
        });         
        this.callParent(arguments);
    },
    reset: function (){
      this.inputSensorType.setValue(0);
      this.comboRooms.setValue(0);
      this.editDeviceName.setValue("")
    },
    setValue:function (value){
       var nMode = 0;
       switch(parseInt(value, 10))
       {
         case 5:
           nMode = 5;
         break;
         
         case 4:
           nMode = 4;
         break;
       }
     
       this.editDeviceName.setValue(unescape(this.dssEditor.editControls.name.getValue()));
       this.comboRooms.setValue(this.dssEditor.editControls.roomID.getValue());
       this.inputSensorType.setValue({deviceMDMode:nMode});
       this.returnValue = nMode;
    },
    isValid:function(){
        return true;
    },
    getValue : function(){
       var returnData = new Object();
       
       returnData.deviceName = this.editDeviceName.getValue();
       returnData.roomID = this.comboRooms.getValue(); 
       returnData.nMode = this.returnValue;
       
       return returnData;
    }
});
